@@ -70,7 +70,6 @@ class AtomViews:
 
 
 class BuilderCore:
-    models: set
 
     def __init__(self, app=None, decorators=None, prefix=None, session=None, tenant=None, lookup=None, **kwargs):
         self.application = app
@@ -82,6 +81,7 @@ class BuilderCore:
         self.model = kwargs.get('model', None)
         self.models = kwargs.get('models', None)
         self.methods = kwargs.get('methods', None)
+        self.blueprint = None
 
         for item in {'model', 'models', 'methods', 'dao', 'session', 'prefix'}:
             if item in kwargs:
@@ -101,8 +101,8 @@ class BuilderCore:
         if app is not None:
             self.init_app(app)
 
-        if self.model:
-            self.register_methods(self.model, app, self.methods)
+        # if self.model:
+        #     self.register_methods(self.model, app, self.methods)
 
     def define_prefix(self, model):
         return f'{self.prefix or ""}/{model.__tablename__}'
@@ -120,16 +120,20 @@ class BuilderCore:
         )
         blueprint.bind(methods)
         # build out routes for this model
-        self.app = blueprint
-        if app:
-            app.register_blueprint(blueprint, url_prefix=self.define_prefix(model))
+        self.blueprint = blueprint
+        # if app:
+        #     app.register_blueprint(blueprint, url_prefix=self.define_prefix(model))
 
     def bind(self, application: Flask):
         if self.model:
-            application.register_blueprint(self.app, url_prefix=self.define_prefix(self.model))
+            self.register_methods(self.model, application, self.methods)
+            application.register_blueprint(self.blueprint, url_prefix=self.define_prefix(self.model))
+            return self
+
         for model in self.models or []:
             methods = DEFAULT_METHOD_SET
             delete = True
+
             dao = None
             if isinstance(model, tuple):
                 methods = model[1].get('methods')
