@@ -2,9 +2,9 @@ from datetime import datetime
 
 from flask import current_app
 from sqlalchemy.exc import IntegrityError
-from sqlalchemy_abc.helpers import columns
-from sqlalchemy_abc.helpers import relationships
-from sqlalchemy_abc.helpers import primarykey
+from sqlalchemy_blender.helpers import columns
+from sqlalchemy_blender.helpers import relationships
+from sqlalchemy_blender.helpers import primarykey
 
 from flask_atomic.database import db
 
