@@ -12,12 +12,12 @@ from handyhttp import HTTPBadRequest
 from handyhttp import HTTPException
 from handyhttp import HTTPNotFound
 
-from sqlalchemy_abc import serialize
-from sqlalchemy_abc import iserialize
-from sqlalchemy_abc import QueryBuffer
-from sqlalchemy_abc.helpers import related
-from sqlalchemy_abc.helpers import columns
-from sqlalchemy_abc.dao import ModelDAO
+from sqlalchemy_blender import serialize
+from sqlalchemy_blender import iserialize
+from sqlalchemy_blender import QueryBuffer
+from sqlalchemy_blender.helpers import related
+from sqlalchemy_blender.helpers import columns
+from sqlalchemy_blender.dao import ModelDAO
 
 
 from .cache import link
