@@ -122,8 +122,6 @@ class RouteBuilder(Blueprint):
         :rtype: HTTPSuccess
         """
 
-        # self.querystring()
-        rels = related(self.model)
         query = QueryBuffer(self.model).all()
         schema = getschema(self.model)
         return HTTPSuccess(self.json(query.data, queryargs=query.queryargs), schema=schema)
