@@ -1,16 +1,15 @@
-from flask import jsonify
-
 
 class BaseHTTPResponse:
-    message: str
+    message: str = ''
     code: int
 
     def __new__(cls, *args, **kwargs):
+        message = kwargs.get('message', None) or cls.message or ''
         if kwargs.get('pack', False):
             return cls
         if len(args):
-            return jsonify(data=args[0], message=cls.message, **kwargs), cls.code
-        return jsonify(message=cls.message, **kwargs), cls.code
+            return dict(data=args[0], message=message, **kwargs), cls.code
+        return dict(message=message, **kwargs), cls.code
 
 
 class HTTPSuccess(BaseHTTPResponse):
